@@ -101,7 +101,7 @@ def WriteIntoRecordFile():
         str(records.arrData[5][records.Index])
 
     data.logfile.write(d+"\n")
-    if(data.debug==1): print d
+#    if(data.debug==1): print "Write to file:",d
 
 
 
