@@ -135,8 +135,12 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
 ###########################################################################
 def showGraph(self,  QtGui):
     if(data.ChangesInGraph==False): 
-        if(data.debug==1): print "------>         Do not redraw, nothing changed!"
+        if(data.debug==1): print "-> Do not redraw, nothing changed!"
         return 
+    if(data.DisplayIsOn==False):
+        if(data.debug==1): print "-> Do not redraw, Display is off!"
+        return
+        
         
 #    print "Show data of file",  data.logfilename
 #    print "----------------------------"
@@ -180,7 +184,7 @@ def showGraph(self,  QtGui):
     
     
     GraphStart_tuple=Index2Tuple(data.GraphStart)
-    if(data.debug==1): print "data.GraphStart",  data.GraphStart,  GraphStart_tuple
+#    if(data.debug==1): print "data.GraphStart",  data.GraphStart,  GraphStart_tuple
     h=int(strftime("%H", GraphStart_tuple))
     m=int(strftime("%M", GraphStart_tuple))
     s=int(strftime("%S", GraphStart_tuple))
