@@ -97,6 +97,17 @@ def main():
     if(data.app_path==""): data.app_path="./"
     else: data.app_path=data.app_path+"/"
     
+    
+    
+    #Load Stylesheet for buttons
+    file = open(data.app_path+"UIStyle.css", 'r')
+    data.UIStyle=""
+    for line in file: data.UIStyle=data.UIStyle+line+"\n"
+    file.close()
+    
+    
+    
+    
     StartWindow = frmStartWindow()    
     StartWindow.show()    
     StartWindow.UpdateScreenStart()
@@ -125,6 +136,7 @@ def main():
         EditUserName()
 
 
+
     DisplayStatusDaemon()
     
     sys.exit(app.exec_())
@@ -387,23 +399,21 @@ class frmStartWindow(QMainWindow):
         self.ui.setupUi(self)
 
         QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), self.StartMeasurementNormal)
-#        QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), self.StartMeasurementQuick)
         QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), self.ShowViewWindow)
-#        QtCore.QObject.connect(self.ui.bConfig, QtCore.SIGNAL("clicked()"), self.ShowConfigWindow)
         QtCore.QObject.connect(self.ui.bSetAlarm, QtCore.SIGNAL("clicked()"), self.SetAlarm)
         
+        #Add styles to buttons
+        self.ui.bCollecting.setStyleSheet(data.UIStyle)
+        self.ui.bSetAlarm.setStyleSheet(data.UIStyle)
+        self.ui.bLog.setStyleSheet(data.UIStyle)
+
+        
         QtCore.QObject.connect(self.ui.actionTest_recording, QtCore.SIGNAL("triggered()"), self.StartMeasurementQuick)
         QtCore.QObject.connect(self.ui.actionSettings, QtCore.SIGNAL("triggered()"), self.ShowConfigWindow)
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
         QtCore.QObject.connect(self.ui.actionHelp, QtCore.SIGNAL("triggered()"), self.ShowHelpWindow)
 
         
-#        file = open(data.app_path+"Info.htm", 'r')
-#        txt=""
-#        for line in file: txt=txt+line+"\n"
-#        file.close()
-#        self.ui.textBrowser.setHtml(txt)
-        
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
@@ -416,6 +426,7 @@ class frmStartWindow(QMainWindow):
 
 
 
+
     ###########################################################################
     # Show the collectring window (hera the data gets visualised during the logging)
     ###########################################################################
@@ -580,7 +591,16 @@ class frmRecordWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
         QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), self.ZoomOut)
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
+        
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
+
+        #Add styles to buttons
+        self.ui.bStop.setStyleSheet(data.UIStyle)
+        self.ui.bRaiseTrigger.setStyleSheet(data.UIStyle)
+        self.ui.bLowerTrigger.setStyleSheet(data.UIStyle)
+        self.ui.bZoomIn.setStyleSheet(data.UIStyle)
+        self.ui.bZoomOut.setStyleSheet(data.UIStyle)
+        self.ui.bEditNote.setStyleSheet(data.UIStyle)
         
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bZoomIn.setIcon(QIcon(data.app_path+"img/"+"zoom-in.png"))
@@ -764,9 +784,29 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
         QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
         QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
+        
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
         QtCore.QObject.connect(self.ui.actionShowRecordData, QtCore.SIGNAL("triggered()"), self.ShowRecordData)
         
+        
+        
+        #Add styles to buttons
+        self.ui.bRaiseTrigger.setStyleSheet(data.UIStyle)
+        self.ui.bLowerTrigger.setStyleSheet(data.UIStyle)
+        self.ui.bZoomIn.setStyleSheet(data.UIStyle)
+        self.ui.bZoomOut.setStyleSheet(data.UIStyle)
+        self.ui.bNext.setStyleSheet(data.UIStyle)
+        self.ui.bLast.setStyleSheet(data.UIStyle)
+        self.ui.bDelete.setStyleSheet(data.UIStyle)
+        self.ui.bOpen.setStyleSheet(data.UIStyle)
+        self.ui.bOpenDate.setStyleSheet(data.UIStyle)
+        self.ui.bEditNote.setStyleSheet(data.UIStyle)
+        self.ui.bLeft.setStyleSheet(data.UIStyle)
+        self.ui.bRight.setStyleSheet(data.UIStyle)
+        
+        
+        
+        
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bLast.setIcon(QIcon(data.app_path+"img/"+"arrow-left-double.png"))
             self.ui.bNext.setIcon(QIcon(data.app_path+"img/"+"arrow-right-double.png"))
@@ -1111,10 +1151,20 @@ class frmConfigWindow(QMainWindow):
         self.ui = Ui_ConfigWindow()
         self.ui.setupUi(self)
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
-              
+        
         QtCore.QObject.connect(self.ui.bEditUserName, QtCore.SIGNAL("clicked()"), self.EditUserName)
         QtCore.QObject.connect(self.ui.SlrDelayStart,SIGNAL("valueChanged(int)"),self.DelaySliderMoved)
         QtCore.QObject.connect(self.ui.SlrYscale,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved)
+
+        #Add styles to buttons
+        self.ui.bEditUserName.setStyleSheet(data.UIStyle)        
+        self.ui.SlrDelayStart.setStyleSheet(data.UIStyle)        
+        self.ui.SlrYscale.setStyleSheet(data.UIStyle)        
+        
+        #Add styles to tick boxes
+        self.ui.cOfflineMode.setStyleSheet(data.UIStyle)    
+        self.ui.cStopAfterAlarm.setStyleSheet(data.UIStyle)   
+        self.ui.cSilentProfile.setStyleSheet(data.UIStyle)   
         
         
 
@@ -1346,10 +1396,12 @@ class frmAlarmTimeWindow(QMainWindow):
         self.ui = Ui_AlarmTimeWindow()
         self.ui.setupUi(self)
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
-        
-
 
         QtCore.QObject.connect(self.ui.bSetAlarm, QtCore.SIGNAL("clicked()"), self.SetAlarm)
+        
+        #Add styles to buttons
+        self.ui.bSetAlarm.setStyleSheet(data.UIStyle)
+        
                 
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
@@ -1449,12 +1501,16 @@ class frmAskForKeepWindow(QMainWindow):
         
         self.ui = Ui_AskForKeepWindow()
         self.ui.setupUi(self)
-#        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
 
         QtCore.QObject.connect(self.ui.bstop_keepRecord, QtCore.SIGNAL("clicked()"), self.KeepRecord)
         QtCore.QObject.connect(self.ui.bstop_removeRecord, QtCore.SIGNAL("clicked()"), self.RemoveRecord)
         QtCore.QObject.connect(self.ui.bcontinue, QtCore.SIGNAL("clicked()"), self.ContinueRecording)
-                
+
+        #Add styles to buttons
+        self.ui.bstop_keepRecord.setStyleSheet(data.UIStyle)
+        self.ui.bstop_removeRecord.setStyleSheet(data.UIStyle)
+        self.ui.bcontinue.setStyleSheet(data.UIStyle)
+        
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bstop_keepRecord.setIcon(QIcon(data.app_path+"img/"+"zoom.png"))
             self.ui.bstop_removeRecord.setIcon(QIcon(data.app_path+"img/"+"edittrash.png"))
